拯救大兵瑞恩 (豆瓣)
Description: 拯救大兵瑞恩电影简介和剧情介绍,拯救大兵瑞恩影评、图片、预告片、影讯、论坛、在线购票
Keywords: 拯救大兵瑞恩,Saving Private Ryan,拯救大兵瑞恩影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.72豆瓣电影Top250

# 拯救大兵瑞恩 Saving Private Ryan (1998)

导演: 史蒂文·斯皮尔伯格
编剧: 罗伯特·罗达特
主演: 汤姆·汉克斯 / 汤姆·塞兹摩尔 / 爱德华·伯恩斯 / 巴里·佩珀 / 亚当·戈德堡 / 范·迪塞尔 / 吉奥瓦尼·瑞比西 / 杰瑞米·戴维斯 / 马特·达蒙 / 特德·丹森 / 保罗·吉亚玛提 / 丹尼斯·法里纳 / 马克斯·马蒂尼 / 丹兰·布鲁诺 / 丹尼尔·切尔奎拉 / 迪米特里·格里特萨斯 / 史蒂夫·格里芬 / 彼得·迈尔斯 / 亚当·肖 / 罗尔夫·萨克森 / 克里·约翰逊 / 洛克兰·艾肯 / 尚恩·约翰逊 / 莱尔德·曼辛托斯 / 安德鲁·斯科特 / 马修·夏普 / 文森特·沃尔什 / 约翰·沙拉恩 / 马丁·哈伯 / 罗非洛·迪格托勒 / 恩里奇·雷德曼 / 米歇尔·埃文斯 / 内森·菲利安 / 利兰·奥瑟 / 大卫·维格 / 瑞恩·赫斯特 / 哈威·普雷斯内尔 / 代尔·戴 / 布莱恩·科兰斯顿 / 大卫·沃尔 / 埃里克·罗兰 / 哈里逊·杨 / 凯思琳·拜荣 / 约翰·德·兰西 / 詹姆斯·恩布里 / 德里克·李 / 若昂·科斯塔·梅内塞斯 / 马克·施泰因迈尔
类型: 剧情 / 战争
官方网站: http://www.rzm.com/pvt.ryan/index.html
制片国家/地区: 美国
语言: 英语 / 法语 / 德语 / 捷克语
上映日期: 1998-11-13(中国大陆) / 1998-07-24(美国)
片长: 169分钟
又名: 雷霆救兵(港) / 抢救雷恩大兵(台) / 拯救大兵雷恩
IMDb: tt0120815
豆瓣评分
引用
9.1
615896人评价
5星
60.2%
4星
33.0%
3星
6.2%
2星
0.4%
1星
0.2%
好于 98% 战争片
好于 98% 剧情片
想看 看过
评价:
推荐

## 拯救大兵瑞恩的剧情简介 · · · · · ·

瑞恩（马特•达蒙 Matt Damon饰 ）是二战期间的美国伞兵，被困在了敌人后方。更不幸的是，他的三个兄弟全部在战争中死亡，如果他也遇难，家中的老母亲将无依无靠。
美国作战总指挥部知道了这个情况，毅然决定组织一个小分队前往救援，其中包括米勒上尉（汤姆•汉克斯 Tom Hanks 饰 ）和翻译厄本（杰里米.戴维斯 Jererry Davies饰）。然而，敌方危险重重，他们一路上随时与死亡打交道。他们非常怀疑，到底值不值得冒着八个人的生命危险，去搭救一个人。
大家一路辗转寻找瑞恩，对于这次搭救行动，有人不满，有人热忱，有人好奇。大家一次次闻到死神的气息，瑞恩的获救付出了沉重的代价。 ©豆瓣

## 拯救大兵瑞恩的演职员 · · · · · · ( 全部 89 )

- 史蒂文·斯皮尔伯格 导演
- 汤姆·汉克斯 饰 Captain Miller
- 汤姆·塞兹摩尔 饰 Sergeant Horvath
- 爱德华·伯恩斯 饰 Private Reiben
- 巴里·佩珀 饰 Private Jackson
- 亚当·戈德堡 饰 Private Mellish

## 拯救大兵瑞恩的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片560 · 添加 )

## 拯救大兵瑞恩的获奖情况 · · · · · · ( 全部 )

- 第71届奥斯卡金像奖
- 最佳影片(提名)
- 马克·戈登 / 史蒂文·斯皮尔伯格 / 伊安·布莱斯 / 加里·莱温索恩

- 第56届金球奖
- 电影类 最佳剧情片

- 第22届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  黑鹰坠落

  兵临城下

  辛德勒的名单

  血战钢锯岭

  钢琴家

  1917

  穿条纹睡衣的男孩

  战争之王

  敦刻尔克

  集结号

我要写短评

## 拯救大兵瑞恩的短评 · · · · · · ( 全部 84177 条 )

热门 / 最新 / 好友

### 3912 有用 Yanisk 看过 2011-12-29 12:12:24

如果没有办法想起他什么样子，就试着想想和他共渡的时光。

### 3590 有用 魏无忌 看过 2008-07-06 23:23:52

战争电影No1，美利坚精神输出大片。

### 364 有用 寂地 看过 2006-01-05 00:20:43

其实电影非常的棒，但是道理和萤火虫之墓地一样．因为实在太真实，让人难受．看到一半就缩到了角落里，再也不想看下去．

### 4086 有用 容安 看过 2011-02-28 22:41:26

厄本这个角色很有意思，懦弱，非常懦弱，还有一种可笑的浪漫和无知的善良。他才是你我他，对战争的残酷抱有一种可耻的畏惧，并对其有好心的幻想。可惜事实并非如此，战争就是你死我活，战争是考验勇气的时刻，而非善心。胆小的也许能活下来，但在战争中，你已经输了。而那些死了的勇士，他们才是胜利者

### 2751 有用 L. 看过 2012-10-20 20:27:09

为什么看中国战争片就感觉high得不行真想打一仗，看外国战争片就觉得战争真可怕和平多好啊。。。。再不在吃饭的时候看战争片了，太胸闷了。

> 更多短评 84177条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 拯救大兵瑞恩的影评 · · · · · · ( 全部 1109 条 )

热门 / 最新 / 好友
Siobhan 2008-07-24 21:51:11

## “长官，我对这事儿有点看法”

有些电影只配充当茶余饭后的消遣，有些电影则注定成为记忆的里程碑。 《拯救大兵瑞恩》无疑属于后者。 一 战争总使人联想到史诗，史诗十有八九会描写战争。 二战是人类历史到目前为止最大规模的一场战争，也是距离我们最近的一首... (展开)
4728 313 340回应 收起
Sweeney Todd 2010-05-23 23:15:12

## 拯救的不只是瑞恩

一部与奥斯卡最佳影片擦肩而过的电影 他没有失去奥斯卡 奥斯卡失去了他 开场的二十分钟二战场景、几乎还原了真实的二战.... 在船上的时候、军官告诉士兵们该怎么做、士兵们亲吻十字架 一打开船门、子弹扫射而来、你该怎么做？ 那就是登上了人间地狱 毫不做作的还原了... (展开)
2183 173 123回应 收起
Ehle 2009-02-05 23:58:14

## 好莱坞历史上最优秀的10部战争片

战争片并不总是血腥和残酷。在斯皮尔伯格的扛鼎之作《拯救大兵瑞恩》之前，许多战争影片对战争残酷的揭示大多是有所保留的。我们在看这些最优秀的战争片时，真的不要仅只用眼睛。 1.《西线无战事》(1930年)：这是一部反映一战的影片，当时十分流行，现在看来也很有震撼力：战... (展开)
1031 200 137回应 收起
十一月的雨 2007-06-08 20:14:20

## 最真实的二战史诗－－《拯救大兵瑞恩》

文：十一月的雨 和身边的大多数朋友不太一样，我不太喜欢战争题材的电影。说的直接点，以前基本上对此不太感冒。经常搞不懂为什么一提起有关战争题材的作品他们总会兴趣倍增滔滔不绝。 这部影片完全改变了我的看法，也是从它开始，我慢慢的懂得了从战争片中发掘人性。 最初... (展开)
428 36 58回应 收起
labrador🌚JKS 2016-10-07 12:56:11

## 大爱自信又忘我的jackson❤️❤️纪念帖

凑巧重看了这部儿时看过的电影 被狙击手jackson迷住 或许长大后对剧情和人物性格更能理解感悟 他看上去与任何一个战士都不同 天生自信 独立 以战斗天赋为傲 信仰让他看上去如此冷静但他也会得瑟 注意这一段他的表情和手部动作，真心自信 （啊哈哈以及最后一张霍瓦特军士的表... (展开)
367 5 40回应 收起
菜小七 2016-08-01 22:48:06

## 这个影片不是在讨论八个人救一个人值不值得

每次在微博上看到有网友说什么去打战啊，我就觉得应该人人都看一看辛德勒的名单或者拯救大兵瑞恩 这样的战争片。 初中历史教育应该统统让老师给学生看一下这些电影。 我们的历史书，以及影视作品对战争残酷的理解和描述都太不够，以至于有那么多人在微博上鼓吹战争，更意识不到... (展开)
337 17 79回应 收起
超越自我 2009-11-21 23:15:28

## 厄本——我有话要说

这确实是一步震撼人心的大片，看完后好多地方都确实值得我们的深思。或许在死亡的面前，每个人都是渺小的。我们没有经历，我们也没有资格去评判他。 他确实不适合战争，在看到他让米勒放走那法西斯时，我对他的是赞同的，人之初，性本善，大家都是有妈妈有家庭的人，既... (展开)
397 134 255回应 收起
ikkin 2019-10-26 21:14:03

## 影史最佳狙击手top3——以杰克森为例，用显微镜读电影中的细节

这篇影评可能有剧透

拯救大兵瑞恩至今已有20余年，每次回看都会重新爱上杰克森这个角色，近年新出许多狙击手为主角的电影，其中也不乏佳片，但外媒评选影史最佳狙击手却永远有这个20年前的配角一个位置，而且雷打不动的前三。 越喜欢这个角色，越对他的着墨不多感到遗憾。他戏份集中在战场上，冷静... (展开)
219 1 22回应 收起
普通人 2005-11-30 14:31:27

## 生之价值——《拯救大兵》

生命是如此脆弱，脆弱到令人心惊的程度。当子弹射入脑颅，鲜血尚未溅到地上；当利刃插进胸腔，心脏仍在舒张抽搐，生命已然逝去，留下的那些些痕迹，也只如流水滑过指缝后，手上残留的水渍般轻易蒸发。史蒂芬用二十五分钟时间，强迫我接受这个震撼—— 身处战争中的人，就如我... (展开)
197 57 48回应 收起
一笔墨迹 2011-12-11 13:24:17

## 止战之殇

An eye for an eye ends up only making the whole world blind 以眼还眼，世界只会更盲目. ——莫罕达斯·卡拉姆昌德·甘地 位于纽约的联合国总部门前有一个冷色调的铸铁雕塑“铸剑为犁”。那是一只枪的造型，... (展开)
155 9 20回应 收起

> 更多影评 1109篇

添加新讨论

## 讨论区 · · · · · ·

发现了一些小细节没有人提到…… | 来自柯彼安的汉堡包 | 8 回应 | 2022-11-19 07:38:51
实在是忍不住了，有些人是眼瞎吗？ | 来自Since | 53 回应 | 2022-11-13 00:36:13
我问一下啊，厄本最后一直躲在那，也不送子弹，不... | 来自芒果不吃芒果 | 15 回应 | 2022-11-12 21:43:31
楼梯德军为什么不杀厄本 | 来自崔悦石 | 116 回应 | 2022-11-09 22:07:35
反战不是不战 | 来自The Lost Man |  | 2022-11-08 17:13:09

> 去这部影片的讨论区（全部223条）

## 关于《拯救大兵瑞恩》的问题 · · · · · · ( 全部25个 )

- 里面有个胆子特别小的拿着一串子弹也没去救同伙的那个人是谁那？ 13人回答
- 其中一个人说 自己和他妈的故事，说道：后来，我妈特意提前回来了，但我却装睡 ？ 9人回答

> 全部25个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 纱织NaNa
  8分钟前 想看
- whcwhcwhc
  11分钟前 看过
- 豆友19982488
  17分钟前 看过

1005978人看过 / 254901人想看

订阅拯救大兵瑞恩的评论:
feed: rss 2.0